@@ -9,10 +9,10 @@ my $key  = $ENV{'CLOUDSERVERS_KEY'}  or die "Need CLOUDSERVERS_KEY environment v
 
 $Net::RackSpace::CloudServers::DEBUG = 1;
 my $CS = Net::RackSpace::CloudServers->new(
-  user => $user,
-  key  => $key,
+    user => $user,
+    key  => $key,
 );
 
-$CS->get_image;
-$CS->get_image_detail(2);
+#$CS->get_image;
+#$CS->get_image_detail(2);
 $CS->get_image_detail;
